/********************************************************************************
** Form generated from reading UI file 'knotifyconfigactionswidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KNOTIFYCONFIGACTIONSWIDGETBASE_H
#define UI_KNOTIFYCONFIGACTIONSWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_KNotifyConfigActionsWidgetBase
{
public:
    QGridLayout *gridLayout;
    QToolButton *Sound_play;
    KUrlRequester *Sound_select;
    QCheckBox *Sound_check;
    QCheckBox *Popup_check;

    void setupUi(QWidget *KNotifyConfigActionsWidgetBase)
    {
        if (KNotifyConfigActionsWidgetBase->objectName().isEmpty())
            KNotifyConfigActionsWidgetBase->setObjectName("KNotifyConfigActionsWidgetBase");
        KNotifyConfigActionsWidgetBase->resize(433, 202);
        gridLayout = new QGridLayout(KNotifyConfigActionsWidgetBase);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        Sound_play = new QToolButton(KNotifyConfigActionsWidgetBase);
        Sound_play->setObjectName("Sound_play");
        Sound_play->setEnabled(false);

        gridLayout->addWidget(Sound_play, 0, 1, 1, 1);

        Sound_select = new KUrlRequester(KNotifyConfigActionsWidgetBase);
        Sound_select->setObjectName("Sound_select");
        Sound_select->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Sound_select->sizePolicy().hasHeightForWidth());
        Sound_select->setSizePolicy(sizePolicy);

        gridLayout->addWidget(Sound_select, 0, 2, 1, 2);

        Sound_check = new QCheckBox(KNotifyConfigActionsWidgetBase);
        Sound_check->setObjectName("Sound_check");

        gridLayout->addWidget(Sound_check, 0, 0, 1, 1);

        Popup_check = new QCheckBox(KNotifyConfigActionsWidgetBase);
        Popup_check->setObjectName("Popup_check");

        gridLayout->addWidget(Popup_check, 1, 0, 1, 4);


        retranslateUi(KNotifyConfigActionsWidgetBase);
        QObject::connect(Sound_check, &QCheckBox::toggled, Sound_play, &QToolButton::setEnabled);
        QObject::connect(Sound_check, SIGNAL(toggled(bool)), Sound_select, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(KNotifyConfigActionsWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *KNotifyConfigActionsWidgetBase)
    {
        Sound_play->setText(QString());
#if QT_CONFIG(tooltip)
        Sound_select->setToolTip(tr2i18n("Select the sound to play", nullptr));
#endif // QT_CONFIG(tooltip)
        Sound_check->setText(tr2i18n("Play a &sound", nullptr));
        Popup_check->setText(tr2i18n("Show a message in a &popup", nullptr));
        (void)KNotifyConfigActionsWidgetBase;
    } // retranslateUi

};

namespace Ui {
    class KNotifyConfigActionsWidgetBase: public Ui_KNotifyConfigActionsWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KNOTIFYCONFIGACTIONSWIDGETBASE_H

